@@ -1,9 +1,8 @@
-
 package ReEntrancyTest;
-
 use strict;
-use vars qw($wohoo $foo);
+use warnings;
 
+our $wohoo;
 use Pod::Constants -debug => 1, -trim => 1, foobar => \$wohoo;
 
 =head1 foobar
